@@ -1,8 +1,10 @@
 import json
+from copy import copy
 from enum import Enum
 from hashlib import sha256
 from json import JSONDecodeError
 from typing import List, Dict, Any, Optional, Union
+
 try:
     from typing import Literal
 except ImportError:
@@ -37,6 +39,7 @@ class MessageType(str, Enum):
     aggregate = "AGGREGATE"
     store = "STORE"
     program = "PROGRAM"
+    forget = "FORGET"
 
 
 class ItemType(str, Enum):
@@ -138,6 +141,18 @@ class StoreContent(BaseContent):
         extra = Extra.allow
 
 
+class ForgetContent(BaseContent):
+    "Content of a FORGET message"
+    hashes: List[str]
+    reason: Optional[str]
+
+    def __hash__(self):
+        # Convert List to Tuple for hashing
+        values = copy(self.__dict__)
+        values["hashes"] = tuple(values["hashes"])
+        return hash(self.__class__) + hash(values.values())
+
+
 class BaseMessage(BaseModel):
     "Base template for all messages"
     id_: Optional[MongodbId] = Field(alias="_id", description="MongoDB metadata")
@@ -239,6 +254,11 @@ class StoreMessage(BaseMessage):
     content: StoreContent
 
 
+class ForgetMessage(BaseMessage):
+    type: Literal[MessageType.forget]
+    content: ForgetContent
+
+
 class ProgramMessage(BaseMessage):
     type: Literal[MessageType.program]
     content: ProgramContent
@@ -266,11 +286,12 @@ def Message(**message_dict: Dict
         MessageType.aggregate: AggregateMessage,
         MessageType.store: StoreMessage,
         MessageType.program: ProgramMessage,
+        MessageType.forget: ForgetMessage,
     }.items():
         if message_dict["type"] == raw_type:
             return message_class(**message_dict)
     else:
-        raise ValueError
+        raise ValueError(f"Unknown message type")
 
 
 class MessagesResponse(BaseModel):
